"use strict";
// Copyright (c) Jupyter Development Team.
// Copyright (c) Microsoft Corporation.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.selectStyles = void 0;
const fast_components_1 = require("@microsoft/fast-components");
const fast_element_1 = require("@microsoft/fast-element");
const fast_foundation_1 = require("@microsoft/fast-foundation");
const fast_web_utilities_1 = require("@microsoft/fast-web-utilities");
const styles_1 = require("../styles");
/**
 * Styles for Select
 * @public
 */
const selectStyles = (context, definition) => fast_element_1.css `
    ${fast_foundation_1.display('inline-flex')} :host {
      --elevation: 14;
      background: ${fast_components_1.neutralFillInputRest};
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
      border: calc(${fast_components_1.strokeWidth} * 1px) solid ${fast_components_1.neutralFillStrongRest};
      box-sizing: border-box;
      color: ${fast_components_1.neutralForegroundRest};
      font-family: ${fast_components_1.bodyFont};
      height: calc(${styles_1.heightNumber} * 1px);
      position: relative;
      user-select: none;
      min-width: 250px;
      outline: none;
      vertical-align: top;
    }

    .listbox {
      ${styles_1.elevation}
      background: ${fast_components_1.neutralLayerFloating};
      border: calc(${fast_components_1.strokeWidth} * 1px) solid ${fast_components_1.neutralStrokeRest};
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
      box-sizing: border-box;
      display: inline-flex;
      flex-direction: column;
      left: 0;
      max-height: calc(var(--max-height) - (${styles_1.heightNumber} * 1px));
      padding: calc(${fast_components_1.designUnit} * 1px) 0;
      overflow-y: auto;
      position: absolute;
      width: 100%;
      z-index: 1;
    }

    .listbox[hidden] {
      display: none;
    }

    .control {
      align-items: center;
      box-sizing: border-box;
      cursor: pointer;
      display: flex;
      font-size: ${fast_components_1.typeRampBaseFontSize};
      font-family: inherit;
      line-height: ${fast_components_1.typeRampBaseLineHeight};
      min-height: 100%;
      padding: 0 calc(${fast_components_1.designUnit} * 2.25px);
      width: 100%;
    }

    :host([minimal]) {
      --density: -4;
      min-width: unset;
    }

    :host(:not([disabled]):hover) {
      background: ${fast_components_1.neutralFillInputHover};
      border-color: ${fast_components_1.neutralFillStrongHover};
    }

    :host(:${fast_foundation_1.focusVisible}) {
      border-color: ${fast_components_1.accentFillFocus};
      box-shadow: 0 0 0 calc((${fast_components_1.focusStrokeWidth} - ${fast_components_1.strokeWidth}) * 1px)
        ${fast_components_1.accentFillFocus};
    }

    :host([disabled]) {
      cursor: ${fast_foundation_1.disabledCursor};
      opacity: ${fast_components_1.disabledOpacity};
    }

    :host([disabled]) .control {
      cursor: ${fast_foundation_1.disabledCursor};
      user-select: none;
    }

    :host([disabled]:hover) {
      background: ${fast_components_1.neutralFillStealthRest};
      color: ${fast_components_1.neutralForegroundRest};
      fill: currentcolor;
    }

    :host(:not([disabled])) .control:active {
      background: ${fast_components_1.neutralFillInputActive};
      border-color: ${fast_components_1.accentFillActive};
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
    }

    :host([open][position='above']) .listbox {
      border-bottom-left-radius: 0;
      border-bottom-right-radius: 0;
    }

    :host([open][position='below']) .listbox {
      border-top-left-radius: 0;
      border-top-right-radius: 0;
    }

    :host([open][position='above']) .listbox {
      border-bottom: 0;
      bottom: calc(${styles_1.heightNumber} * 1px);
    }

    :host([open][position='below']) .listbox {
      border-top: 0;
      top: calc(${styles_1.heightNumber} * 1px);
    }

    .selected-value {
      flex: 1 1 auto;
      font-family: inherit;
      text-align: start;
      white-space: nowrap;
      text-overflow: ellipsis;
      overflow: hidden;
    }

    .indicator {
      flex: 0 0 auto;
      margin-inline-start: 1em;
    }

    slot[name='listbox'] {
      display: none;
      width: 100%;
    }

    :host([open]) slot[name='listbox'] {
      display: flex;
      position: absolute;
      ${styles_1.elevation}
    }

    .end {
      margin-inline-start: auto;
    }

    .start,
    .end,
    .indicator,
    .select-indicator,
    ::slotted(svg) {
      /* TODO: adaptive typography https://github.com/microsoft/fast/issues/2432 */
      fill: currentcolor;
      height: 1em;
      min-height: calc(${fast_components_1.designUnit} * 4px);
      min-width: calc(${fast_components_1.designUnit} * 4px);
      width: 1em;
    }

    ::slotted([role='option']),
    ::slotted(option) {
      flex: 0 0 auto;
    }
  `.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
        :host(:not([disabled]):hover),
        :host(:not([disabled]):active) {
          border-color: ${fast_web_utilities_1.SystemColors.Highlight};
        }

        :host(:not([disabled]):${fast_foundation_1.focusVisible}) {
          background-color: ${fast_web_utilities_1.SystemColors.ButtonFace};
          box-shadow: 0 0 0 calc(${fast_components_1.focusStrokeWidth} * 1px)
            ${fast_web_utilities_1.SystemColors.Highlight};
          color: ${fast_web_utilities_1.SystemColors.ButtonText};
          fill: currentcolor;
          forced-color-adjust: none;
        }

        :host(:not([disabled]):${fast_foundation_1.focusVisible}) .listbox {
          background: ${fast_web_utilities_1.SystemColors.ButtonFace};
        }

        :host([disabled]) {
          border-color: ${fast_web_utilities_1.SystemColors.GrayText};
          background-color: ${fast_web_utilities_1.SystemColors.ButtonFace};
          color: ${fast_web_utilities_1.SystemColors.GrayText};
          fill: currentcolor;
          opacity: 1;
          forced-color-adjust: none;
        }

        :host([disabled]:hover) {
          background: ${fast_web_utilities_1.SystemColors.ButtonFace};
        }

        :host([disabled]) .control {
          color: ${fast_web_utilities_1.SystemColors.GrayText};
          border-color: ${fast_web_utilities_1.SystemColors.GrayText};
        }

        :host([disabled]) .control .select-indicator {
          fill: ${fast_web_utilities_1.SystemColors.GrayText};
        }

        :host(:${fast_foundation_1.focusVisible}) ::slotted([aria-selected="true"][role="option"]),
            :host(:${fast_foundation_1.focusVisible}) ::slotted(option[aria-selected="true"]),
            :host(:${fast_foundation_1.focusVisible}) ::slotted([aria-selected="true"][role="option"]:not([disabled])) {
          background: ${fast_web_utilities_1.SystemColors.Highlight};
          border-color: ${fast_web_utilities_1.SystemColors.ButtonText};
          box-shadow: 0 0 0 calc((${fast_components_1.focusStrokeWidth} - ${fast_components_1.strokeWidth}) * 1px)
            ${fast_web_utilities_1.SystemColors.HighlightText};
          color: ${fast_web_utilities_1.SystemColors.HighlightText};
          fill: currentcolor;
        }

        .start,
        .end,
        .indicator,
        .select-indicator,
        ::slotted(svg) {
          color: ${fast_web_utilities_1.SystemColors.ButtonText};
          fill: currentcolor;
        }
      `));
exports.selectStyles = selectStyles;
//# sourceMappingURL=select.styles.js.map