"use strict";
// Copyright (c) Jupyter Development Team.
// Copyright (c) Microsoft Corporation.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.tabStyles = void 0;
const fast_components_1 = require("@microsoft/fast-components");
const fast_element_1 = require("@microsoft/fast-element");
const fast_foundation_1 = require("@microsoft/fast-foundation");
const fast_web_utilities_1 = require("@microsoft/fast-web-utilities");
const styles_1 = require("../styles");
/**
 * Styles for Tab
 * @public
 */
const tabStyles = (context, definition) => fast_element_1.css `
    ${fast_foundation_1.display('inline-flex')} :host {
      box-sizing: border-box;
      font-family: ${fast_components_1.bodyFont};
      font-size: ${fast_components_1.typeRampBaseFontSize};
      line-height: ${fast_components_1.typeRampBaseLineHeight};
      height: calc(${styles_1.heightNumber} * 1px);
      padding: calc(${fast_components_1.designUnit} * 5px) calc(${fast_components_1.designUnit} * 4px);
      color: ${fast_components_1.neutralForegroundHint};
      fill: currentcolor;
      border-radius: 0 0 calc(${fast_components_1.controlCornerRadius} * 1px)
        calc(${fast_components_1.controlCornerRadius} * 1px);
      border: calc(${fast_components_1.strokeWidth} * 1px) solid transparent;
      align-items: center;
      grid-row: 2;
      justify-content: center;
      cursor: pointer;
    }

    :host(:hover) {
      color: ${fast_components_1.neutralForegroundRest};
      fill: currentcolor;
    }

    :host(:active) {
      color: ${fast_components_1.neutralForegroundRest};
      fill: currentcolor;
    }

    :host([disabled]) {
      cursor: ${fast_foundation_1.disabledCursor};
      opacity: ${fast_components_1.disabledOpacity};
    }

    :host([disabled]:hover) {
      color: ${fast_components_1.neutralForegroundHint};
      background: ${fast_components_1.neutralFillStealthRest};
    }

    :host([aria-selected='true']) {
      background: ${fast_components_1.neutralFillRest};
      color: ${fast_components_1.neutralForegroundRest};
      fill: currentcolor;
    }

    :host([aria-selected='true']:hover) {
      background: ${fast_components_1.neutralFillHover};
      color: ${fast_components_1.neutralForegroundRest};
      fill: currentcolor;
    }

    :host([aria-selected='true']:active) {
      background: ${fast_components_1.neutralFillActive};
      color: ${fast_components_1.neutralForegroundRest};
      fill: currentcolor;
    }

    :host(:${fast_foundation_1.focusVisible}) {
      outline: none;
      border: calc(${fast_components_1.strokeWidth} * 1px) solid ${fast_components_1.accentFillFocus};
    }

    :host(:focus) {
      outline: none;
    }

    :host(.vertical) {
      justify-content: end;
      grid-column: 2;
      border-bottom-left-radius: 0;
      border-top-right-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
    }

    :host(.vertical[aria-selected='true']) {
      z-index: 2;
    }

    :host(.vertical:hover) {
      color: ${fast_components_1.neutralForegroundRest};
    }

    :host(.vertical:active) {
      color: ${fast_components_1.neutralForegroundRest};
    }

    :host(.vertical:hover[aria-selected='true']) {
    }
  `.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
        :host {
          forced-color-adjust: none;
          border-color: transparent;
          color: ${fast_web_utilities_1.SystemColors.ButtonText};
          fill: currentcolor;
        }
        :host(:hover),
        :host(.vertical:hover),
        :host([aria-selected='true']:hover) {
          background: ${fast_web_utilities_1.SystemColors.Highlight};
          color: ${fast_web_utilities_1.SystemColors.HighlightText};
          fill: currentcolor;
        }
        :host([aria-selected='true']) {
          background: ${fast_web_utilities_1.SystemColors.HighlightText};
          color: ${fast_web_utilities_1.SystemColors.Highlight};
          fill: currentcolor;
        }
        :host(:${fast_foundation_1.focusVisible}) {
          border-color: ${fast_web_utilities_1.SystemColors.ButtonText};
          box-shadow: none;
        }
        :host([disabled]),
        :host([disabled]:hover) {
          opacity: 1;
          color: ${fast_web_utilities_1.SystemColors.GrayText};
          background: ${fast_web_utilities_1.SystemColors.ButtonFace};
        }
      `));
exports.tabStyles = tabStyles;
//# sourceMappingURL=tab.styles.js.map