"use strict";
// Copyright (c) Jupyter Development Team.
// Copyright (c) Microsoft Corporation.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.toolbarStyles = void 0;
const fast_components_1 = require("@microsoft/fast-components");
const fast_element_1 = require("@microsoft/fast-element");
const fast_foundation_1 = require("@microsoft/fast-foundation");
const fast_web_utilities_1 = require("@microsoft/fast-web-utilities");
/**
 * Styles for the Toolbar
 *
 * @public
 */
const toolbarStyles = (context, definition) => fast_element_1.css `
    ${fast_foundation_1.display('inline-flex')} :host {
      --toolbar-item-gap: calc(
        (var(--design-unit) + calc(var(--density) + 2)) * 1px
      );
      background-color: ${fast_components_1.fillColor};
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
      fill: currentcolor;
      padding: var(--toolbar-item-gap);
    }

    :host(${fast_foundation_1.focusVisible}) {
      outline: calc(${fast_components_1.strokeWidth} * 1px) solid ${fast_components_1.accentFillFocus};
    }

    .positioning-region {
      align-items: flex-start;
      display: inline-flex;
      flex-flow: row wrap;
      justify-content: flex-start;
    }

    :host([orientation='vertical']) .positioning-region {
      flex-direction: column;
    }

    ::slotted(:not([slot])) {
      flex: 0 0 auto;
      margin: 0 var(--toolbar-item-gap);
    }

    :host([orientation='vertical']) ::slotted(:not([slot])) {
      margin: var(--toolbar-item-gap) 0;
    }

    .start,
    .end {
      display: flex;
      margin: auto;
      margin-inline: 0;
    }

    ::slotted(svg) {
      /* TODO: adaptive typography https://github.com/microsoft/fast/issues/2432 */
      width: 16px;
      height: 16px;
    }
  `.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
        :host(:${fast_foundation_1.focusVisible}) {
          box-shadow: 0 0 0 calc(${fast_components_1.focusStrokeWidth} * 1px)
            ${fast_web_utilities_1.SystemColors.Highlight};
          color: ${fast_web_utilities_1.SystemColors.ButtonText};
          forced-color-adjust: none;
        }
      `));
exports.toolbarStyles = toolbarStyles;
//# sourceMappingURL=toolbar.styles.js.map